pub enum EscapingError {
EscapeAtEndOfString {
text: String,
},
InvalidEscapedCharacter {
text: String,
character: char,
},
}Expand description
Escaping errors generated by escaping functions.
These errors are not generated by the parser, so you don’t need to worry about them if you are using the parser, only if you are using the escaping functions directly.
Variants